/*
 Color Detection Project

 The circuit:
 * LDR voltage devider output connected to analog pin 0.  
 * Red   LED connected from digital pin 2 thorough 330 ohm resistor
 * Green LED connected from digital pin 3 thorough 330 ohm resistor
 * Blue  LED connected from digital pin 4 thorough 330 ohm resistor
 
 created by:
 Eng. Alaa Al Nassan
 Founder, ROBOSAN Solutions
 robosan.weebly.com
 */
#include <math.h>
// used pins:
#define LDR       A0 // the LDR is attached to Analog input pin 0
#define LED_RED   2  // output Red LED is attached to digital pin 2
#define LED_GREEN 3  // output Green LED is attached to digital pin 3
#define LED_BLUE  4  // output Blue LED is attached to digital pin 4

#define FLASH_T  5 // time tuned for turning the led ON and to wait the ADC converstion to finish
// global variables
int redValue = 0;    // value read during LED_RED on
int greenValue = 0;  // value read during LED_GREEN on
int blueValue = 0;   // value read during LED_BLUE on
int color = 0;

void setup() {
  // initialize serial communications at 9600 bps:
  Serial.begin(9600);
  
  pinMode(LED_RED, OUTPUT);
  pinMode(LED_GREEN, OUTPUT);
  pinMode(LED_BLUE, OUTPUT);
  pinMode(LDR, INPUT);
}

void loop() {

  // call three functions for RGB, each:
  // turns the LED on, reads LDR value, return the result
  redValue = flash_Red(); 
  greenValue = flash_Green();   
  blueValue = flash_Blue();

  // call minimum (min) function from math library
  // Since min function only takes two arguments, it should be called twice
  // first between red and green.
      color = min(redValue, greenValue);
  // Second between the result and blue
      color = min( color, blueValue);
      
  if (color== redValue){
      Serial.println("Color is RED");
  }
   else if (color== greenValue){
      Serial.println("Color is GREEN");
  }
   else if (color== blueValue){
      Serial.println("Color is BLUE");  
  }

//  delay(100);
}

// Three subroutins for every color, each:
// make corresponing LED color ON then reads LDR then OFF
// Inputs: none
// Outputs: color value

int flash_Red(void){
    digitalWrite(LED_RED, HIGH);
    delay(FLASH_T);
    redValue = analogRead(LDR);
    delay(FLASH_T);
    digitalWrite(LED_RED, LOW);

    return redValue;    
  }

int flash_Green(void){
    digitalWrite(LED_GREEN, HIGH);
    delay(FLASH_T);
    greenValue = analogRead(LDR);
    delay(FLASH_T);
    digitalWrite(LED_GREEN, LOW);
    
    return greenValue;
    }
    
int flash_Blue(void){
    digitalWrite(LED_BLUE, HIGH);
    delay(FLASH_T);
    blueValue = analogRead(LDR);
    delay(FLASH_T);
    digitalWrite(LED_BLUE, LOW);

    return blueValue;
  }

